#
# spec file for package binwalk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           binwalk
Version:        2.2.0
Release:        bp153.1.14
Summary:        Firmware Analysis Tool
License:        MIT
URL:            https://github.com/devttys0/binwalk
Source:         https://github.com/devttys0/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-curses
BuildRequires:  python3-setuptools
# Depends on libmagic.
Requires:       file
Requires:       python3-curses
# Depends on libfuzzy.
Requires:       ssdeep
Recommends:     bzip2
Recommends:     cabextract
Recommends:     cpio
Recommends:     gzip
Recommends:     unrar
Recommends:     xz
Recommends:     zlib
Suggests:       java
BuildArch:      noarch
%if 0%{?suse_version} > 1500
Recommends:     p7zip-full
%else
Recommends:     p7zip
%endif

%description
Binwalk is a tool for searching a given binary image for embedded
files and executable code. Specifically, it is designed for
identifying files and code embedded inside of firmware images.
Binwalk uses the libmagic library, so it is compatible with magic
signatures created for the Unix file utility. Binwalk also includes
a custom magic signature file which contains improved signatures
for files that are commonly found in firmware images such as
compressed/archived files, firmware headers, Linux kernels,
bootloaders, filesystems, etc.

%prep
%setup -q

%build
%python3_build

%install
%python3_install
chmod 644 API.md

%files
%license LICENSE
%doc API.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-*

%changelog
* Thu Feb  6 2020 Klaus Kämpf <kkaempf@suse.com>
- Update to version 2.2.0
  - no further information available -
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Aug 10 2018 tchvatal@suse.com
- Use only python3 variant
- Drop argparse dependency
- Use %%license macro
* Mon Jul  2 2018 kstreitova@suse.com
- Recommends p7zip-full for TW as 7z binary used in binwalk was
  moved there
* Wed Dec 23 2015 aloisio@gmx.com
- Update to version 2.1.1:
  * Many bug fixes
  * New/improved file signatures
  * Disassembly scans (using the Capstone Engine)
  * Improved raw Deflate compression detection and extraction
  * Raw LZMA compression detection and extraction
  * Improved false positive detection for common compressions
    (Zlib, LZMA)
  * An IDA plugin for running binwalk inside of IDA
  * Integration of better extraction utilities (e.g., sasquatch
    for SquashFS, jefferson for JFFS2)
  * Removal of all C library dependencies, including
    libmagic - pure Python!
  * Native Windows support!
* Mon Sep 14 2015 sor.alexei@meowr.ru
- Use Python 3.x in new openSUSE releases.
- Use built-in pyqtgraph.
- Require "file" instead of python-magic as a shadow ABI-agnostic
  libmagic dependency and "ssdeep" instead of "libfuzzy2".
- Dependencies fixes.
- Remove manpage generation from "binwalk --help": sometimes it
  makes package build to fail.
- Spec cleanup.
* Wed Jul  1 2015 aloisio@gmx.com
- Added requirement for python-curses
* Mon Aug  4 2014 boris@steki.net
- updated to latest upstream 2.0.1
  + Python3 support
  + Raw deflate detection/extraction
  + Improved API
  + Improved speed
  + More (and improved) signatures
  + Faster entropy scans
- Project has moved from google code hosting to github
* Mon Sep 23 2013 vcizek@suse.com
- update to 1.2.1
  * complete re-write in Python and includes new features and
  a scriptable Python module
  * several new features, including recursive scanning and extraction,
  strings and entropy analysis, and plugin support
  * major speed improvements and regex filter support,
  as well as bug fixes and signature updates
  * adds the --extract option and extends --dd, allowing auto extraction
  and auto decompression of extracted files
  * Improved signatures and scan speed
* Tue Oct 30 2012 boris@steki.net
- updated to latest upstream 0.4.5
  * Fixed magic file white space parsing bug.
  * Fixed memory leak when more than one target file was specified.
  * Added --dd option for auto-extraction of files.
  * Bug fixes, signature updates
  * Much improved scanning speed (thanks dannyb!).
  * New options (--grep, --raw-bytes).
  * Improved filtering.
  * Various bug fixes and signature updates.
  * Improved signature matching for SquashFS file systems.
  * Added support for Linux block devices.
  * Added support for building against libmagic.
  * Added ability to optionally disable update features.
* Tue Aug 23 2011 boris@steki.net
- Initial packaging of 0.3.8 version
